==> demoiselle-jsf-2.5.0-RC1-sources.jar: br/gov/frameworkdemoiselle/template/AbstractPageBean.java <==
/*
 * Demoiselle Framework
 * Copyright (C) 2010 SERPRO
 * ----------------------------------------------------------------------------
 * This file is part of Demoiselle Framework.
 * 
 * Demoiselle Framework is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License version 3
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License version 3
 * along with this program; if not,  see <http://www.gnu.org/licenses/>
 * or write to the Free Software Foundation, Inc., 51 Franklin Street,
 * Fifth Floor, Boston, MA  02110-1301, USA.
 * ----------------------------------------------------------------------------
 * Este arquivo é parte do Framework Demoiselle.
 * 
 * O Framework Demoiselle é um software livre; você pode redistribuí-lo e/ou
 * modificá-lo dentro dos termos da GNU LGPL versão 3 como publicada pela Fundação
 * do Software Livre (FSF).
 * 
 * Este programa é distribuído na esperança que possa ser útil, mas SEM NENHUMA
 * GARANTIA; sem uma garantia implícita de ADEQUAÇÃO a qualquer MERCADO ou
 * APLICAÇÃO EM PARTICULAR. Veja a Licença Pública Geral GNU/LGPL em português
 * para maiores detalhes.
 * 
 * Você deve ter recebido uma cópia da GNU LGPL versão 3, sob o título
 * "LICENCA.txt", junto com esse programa. Se não, acesse <http://www.gnu.org/licenses/>
 * ou escreva para a Fundação do Software Livre (FSF) Inc.,
 * 51 Franklin St, Fifth Floor, Boston, MA 02111-1301, USA.
 */
package br.gov.frameworkdemoiselle.template;

import javax.faces.context.FacesContext;
import javax.inject.Inject;

import br.gov.frameworkdemoiselle.annotation.NextView;
import br.gov.frameworkdemoiselle.annotation.PreviousView;

/**
 * Template Managed AuthenticationBean class that implements the methods defined by the interface PageBean.
 * 
 * @author SERPRO
 * @see PageBean
 */
public abstract class AbstractPageBean implements PageBean {

	private static final long serialVersionUID = 1L;

	@Inject
	private FacesContext facesContext;

	private String nextView;

	private String previousView;

	@Override
	public String getCurrentView() {
		return facesContext.getViewRoot().getViewId();
	}

	@Override
	public String getNextView() {

		if (nextView == null) {
			NextView annotation = this.getClass().getAnnotation(NextView.class);

			if (annotation != null) {
				nextView = annotation.value();
			} else {
				// TODO Lançar exceção orientando o usuário a anotar sua classe com essa anotação aí ou então
				// sobre-escrever este método.
			}
		}

		return nextView;
	}

	@Override
	public String getPreviousView() {

		if (previousView == null) {
			PreviousView annotation = this.getClass().getAnnotation(PreviousView.class);

			if (annotation != null) {
				previousView = annotation.value();
			} else {
				// TODO Lançar exceção orientando o usuário a anotar sua classe com essa anotação aí ou então
				// sobre-escrever este método.
			}
		}

		return previousView;
	}

	@Override
	public String getTitle() {
		// TODO Auto-generated method stub
		return null;
	}
}

==> demoiselle-jsf-2.5.2-RC1-sources.jar: br/gov/frameworkdemoiselle/template/AbstractPageBean.java <==
/*
 * Demoiselle Framework
 * Copyright (C) 2010 SERPRO
 * ----------------------------------------------------------------------------
 * This file is part of Demoiselle Framework.
 * 
 * Demoiselle Framework is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License version 3
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License version 3
 * along with this program; if not,  see <http://www.gnu.org/licenses/>
 * or write to the Free Software Foundation, Inc., 51 Franklin Street,
 * Fifth Floor, Boston, MA  02110-1301, USA.
 * ----------------------------------------------------------------------------
 * Este arquivo é parte do Framework Demoiselle.
 * 
 * O Framework Demoiselle é um software livre; você pode redistribuí-lo e/ou
 * modificá-lo dentro dos termos da GNU LGPL versão 3 como publicada pela Fundação
 * do Software Livre (FSF).
 * 
 * Este programa é distribuído na esperança que possa ser útil, mas SEM NENHUMA
 * GARANTIA; sem uma garantia implícita de ADEQUAÇÃO a qualquer MERCADO ou
 * APLICAÇÃO EM PARTICULAR. Veja a Licença Pública Geral GNU/LGPL em português
 * para maiores detalhes.
 * 
 * Você deve ter recebido uma cópia da GNU LGPL versão 3, sob o título
 * "LICENCA.txt", junto com esse programa. Se não, acesse <http://www.gnu.org/licenses/>
 * ou escreva para a Fundação do Software Livre (FSF) Inc.,
 * 51 Franklin St, Fifth Floor, Boston, MA 02111-1301, USA.
 */
package br.gov.frameworkdemoiselle.template;

import javax.faces.context.FacesContext;

import br.gov.frameworkdemoiselle.annotation.NextView;
import br.gov.frameworkdemoiselle.annotation.PreviousView;
import br.gov.frameworkdemoiselle.util.Beans;

/**
 * Template Managed AuthenticationBean class that implements the methods defined by the interface PageBean.
 * 
 * @author SERPRO
 * @see PageBean
 */
public abstract class AbstractPageBean implements PageBean {

	private static final long serialVersionUID = 1L;

	private String nextView;

	private String previousView;

	@Override
	public String getCurrentView() {
		FacesContext facesContext = Beans.getReference(FacesContext.class);
		return facesContext.getViewRoot().getViewId();
	}

	@Override
	public String getNextView() {

		if (nextView == null) {
			NextView annotation = this.getClass().getAnnotation(NextView.class);

			if (annotation != null) {
				nextView = annotation.value();
			} else {
				// TODO Lançar exceção orientando o usuário a anotar sua classe com essa anotação aí ou então
				// sobre-escrever este método.
			}
		}

		return nextView;
	}

	@Override
	public String getPreviousView() {

		if (previousView == null) {
			PreviousView annotation = this.getClass().getAnnotation(PreviousView.class);

			if (annotation != null) {
				previousView = annotation.value();
			} else {
				// TODO Lançar exceção orientando o usuário a anotar sua classe com essa anotação aí ou então
				// sobre-escrever este método.
			}
		}

		return previousView;
	}

	@Override
	public String getTitle() {
		// TODO Auto-generated method stub
		return null;
	}
}
